All of lore.kernel.org
 help / color / mirror / Atom feed
From: Hannes Reinecke <hare@suse.de>
To: Damien LeMoal <damien.lemoal@wdc.com>
Cc: linux-ide@vger.kernel.org, Hannes Reinecke <hare@suse.de>
Subject: [PATCH 13/68] libata: revamp ata_get_cmd_descript()
Date: Tue, 21 Dec 2021 08:20:36 +0100	[thread overview]
Message-ID: <20211221072131.46673-14-hare@suse.de> (raw)
In-Reply-To: <20211221072131.46673-1-hare@suse.de>

Rename ata_get_cmd_descrip() to ata_get_cmd_name() and simplify
it to return "unknown" instead of NULL.

Signed-off-by: Hannes Reinecke <hare@suse.de>
---
 drivers/ata/libata-acpi.c |  4 +---
 drivers/ata/libata-eh.c   | 22 +++++++++-------------
 drivers/ata/libata.h      |  2 +-
 3 files changed, 11 insertions(+), 17 deletions(-)

diff --git a/drivers/ata/libata-acpi.c b/drivers/ata/libata-acpi.c
index 7007377880ce..9e1e62b9cf63 100644
--- a/drivers/ata/libata-acpi.c
+++ b/drivers/ata/libata-acpi.c
@@ -664,9 +664,7 @@ static int ata_acpi_run_tf(struct ata_device *dev,
 		pptf = &ptf;
 	}
 
-	descr = ata_get_cmd_descript(tf.command);
-	if (!descr)
-		descr = "unknown";
+	descr = ata_get_cmd_name(tf.command);
 
 	if (!ata_acpi_filter_tf(dev, &tf, pptf)) {
 		rtf = tf;
diff --git a/drivers/ata/libata.h b/drivers/ata/libata.h
index 4a8f4623cfe5..2144065e762c 100644
--- a/drivers/ata/libata.h
+++ b/drivers/ata/libata.h
@@ -166,7 +166,7 @@ extern void ata_eh_about_to_do(struct ata_link *link, struct ata_device *dev,
 extern void ata_eh_done(struct ata_link *link, struct ata_device *dev,
 			unsigned int action);
 extern void ata_eh_autopsy(struct ata_port *ap);
-const char *ata_get_cmd_descript(u8 command);
+const char *ata_get_cmd_name(u8 command);
 extern void ata_eh_report(struct ata_port *ap);
 extern int ata_eh_reset(struct ata_link *link, int classify,
 			ata_prereset_fn_t prereset, ata_reset_fn_t softreset,
diff --git a/drivers/ata/libata-eh.c b/drivers/ata/libata-eh.c
index 69f51616d8bd..8bf52a6239aa 100644
--- a/drivers/ata/libata-eh.c
+++ b/drivers/ata/libata-eh.c
@@ -2080,16 +2080,15 @@ void ata_eh_autopsy(struct ata_port *ap)
 }
 
 /**
  *	ata_get_cmd_descript - get description for ATA command
  *	@command: ATA command code to get description for
  *
  *	Return a textual description of the given command, or NULL if the
  *	command is not known.
  *
  *	LOCKING:
  *	None
  */
-const char *ata_get_cmd_descript(u8 command)
+const char *ata_get_cmd_name(u8 command)
 {
 #ifdef CONFIG_ATA_VERBOSE_ERROR
 	static const struct
@@ -2197,9 +2196,9 @@ const char *ata_get_cmd_descript(u8 command)
 			return cmd_descr[i].text;
 #endif
 
-	return NULL;
+	return "unknown";
 }
-EXPORT_SYMBOL_GPL(ata_get_cmd_descript);
+EXPORT_SYMBOL_GPL(ata_get_cmd_name);
 
 /**
  *	ata_eh_link_report - report error handling to user
@@ -2348,12 +2347,9 @@ static void ata_eh_link_report(struct ata_link *link)
 			}
 			__scsi_format_command(cdb_buf, sizeof(cdb_buf),
 					      cdb, cdb_len);
-		} else {
-			const char *descr = ata_get_cmd_descript(cmd->command);
-			if (descr)
-				ata_dev_err(qc->dev, "failed command: %s\n",
-					    descr);
-		}
+		} else
+			ata_dev_err(qc->dev, "failed command: %s\n",
+				    ata_get_cmd_name(cmd->command));
 
 		ata_dev_err(qc->dev,
 			"cmd %02x/%02x:%02x:%02x:%02x:%02x/%02x:%02x:%02x:%02x:%02x/%02x "
@@ -2080,16 +2080,15 @@ void ata_eh_autopsy(struct ata_port *ap)
 
 /**
- *	ata_get_cmd_descript - get description for ATA command
- *	@command: ATA command code to get description for
+ *	ata_get_cmd_name - get name for ATA command
+ *	@command: ATA command code to get name for
  *
@@ -2080,16 +2080,15 @@ void ata_eh_autopsy(struct ata_port *ap)
  *
- *	Return a textual description of the given command, or NULL if the
- *	command is not known.
+ *	Return a textual name of the given command or "unknown"
  *
  *	LOCKING:
-- 
2.29.2


  parent reply	other threads:[~2021-12-21  7:22 UTC|newest]

Thread overview: 82+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-12-21  7:20 [PATCHv3 00/68] libata: rework logging, take II Hannes Reinecke
2021-12-21  7:20 ` [PATCH 01/68] libata: remove pointless debugging messages Hannes Reinecke
2021-12-21  7:20 ` [PATCH 02/68] libata: whitespace cleanup Hannes Reinecke
2021-12-21  7:20 ` [PATCH 03/68] libata: Add ata_port_classify() helper Hannes Reinecke
2021-12-30  5:12   ` Damien Le Moal
2021-12-21  7:20 ` [PATCH 04/68] libata: move ata_dump_id() to dynamic debugging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 05/68] libata: sanitize ATA_HORKAGE_DUMP_ID Hannes Reinecke
2021-12-21  7:20 ` [PATCH 06/68] libata: add reset tracepoints Hannes Reinecke
2021-12-21  7:20 ` [PATCH 07/68] libata: add qc_prep tracepoint Hannes Reinecke
2021-12-21  7:20 ` [PATCH 08/68] libata: tracepoints for bus-master DMA Hannes Reinecke
2021-12-30  5:13   ` Damien Le Moal
2021-12-21  7:20 ` [PATCH 09/68] libata-sff: tracepoints for HSM state machine Hannes Reinecke
2021-12-21  7:20 ` [PATCH 10/68] libata-scsi: drop DPRINTK calls for cdb translation Hannes Reinecke
2021-12-21  7:20 ` [PATCH 11/68] libata: add tracepoints for ATA error handling Hannes Reinecke
2021-12-21  7:20 ` [PATCH 12/68] libata: move ata_{port,link,dev}_dbg to standard dev_XXX() macros Hannes Reinecke
2021-12-21  7:20 ` Hannes Reinecke [this message]
2021-12-30  5:13   ` [PATCH 13/68] libata: revamp ata_get_cmd_descript() Damien Le Moal
2021-12-21  7:20 ` [PATCH 14/68] libata: move DPRINTK to ata debugging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 15/68] sata_mv: kill 'port' argument in mv_dump_all_regs() Hannes Reinecke
2021-12-21  7:20 ` [PATCH 16/68] sata_mv: replace DPRINTK with dynamic debugging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 17/68] pata_octeon_cf: remove DPRINTK() macro in interrupt context Hannes Reinecke
2021-12-21  7:20 ` [PATCH 18/68] pdc_adma: Remove DPRINTK call Hannes Reinecke
2021-12-21  7:20 ` [PATCH 19/68] sata_fsl: move DPRINTK to ata debugging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 20/68] sata_rcar: replace DPRINTK() with ata_port_dbg() Hannes Reinecke
2021-12-21  7:20 ` [PATCH 21/68] sata_qstor: " Hannes Reinecke
2021-12-21  7:20 ` [PATCH 22/68] pata_pdc2027x: Replace PDPRINTK() with standard ata logging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 23/68] libata: remove pointless VPRINTK() calls Hannes Reinecke
2021-12-21  7:20 ` [PATCH 24/68] ahci: Drop pointless VPRINTK() calls and convert the remaining ones Hannes Reinecke
2021-12-21  7:20 ` [PATCH 25/68] pdc_adma: Drop pointless VPRINTK() calls and remove disabled NCQ debugging Hannes Reinecke
2021-12-21  7:20 ` [PATCH 26/68] pata_octeon_cf: Drop pointless VPRINTK() calls and convert the remaining one Hannes Reinecke
2021-12-21  7:20 ` [PATCH 27/68] pata_via: Drop pointless VPRINTK() calls Hannes Reinecke
2021-12-21  7:20 ` [PATCH 28/68] sata_promise: Drop pointless VPRINTK() calls and convert the remaining ones Hannes Reinecke
2021-12-21  7:20 ` [PATCH 29/68] sata_qstor: Drop pointless VPRINTK() calls Hannes Reinecke
2021-12-21  7:20 ` [PATCH 30/68] sata_rcar: " Hannes Reinecke
2021-12-21  7:20 ` [PATCH 31/68] sata_inic162x: " Hannes Reinecke
2021-12-21  7:20 ` [PATCH 32/68] sata_mv: Drop pointless VPRINTK() call and convert the remaining one Hannes Reinecke
2021-12-21  7:20 ` [PATCH 33/68] sata_nv: drop pointless VPRINTK() calls and convert remaining ones Hannes Reinecke
2021-12-21  7:20 ` [PATCH 34/68] sata_fsl: convert VPRINTK() calls to ata_port_dbg() Hannes Reinecke
2021-12-21  7:20 ` [PATCH 35/68] sata_sil: Drop pointless VPRINTK() calls Hannes Reinecke
2021-12-21  7:20 ` [PATCH 36/68] sata_sx4: Drop pointless VPRINTK() calls and convert the remaining ones Hannes Reinecke
2021-12-21  7:21 ` [PATCH 37/68] sata_sx4: add module parameter 'dimm_test' Hannes Reinecke
2021-12-21  7:21 ` [PATCH 38/68] libata: drop ata_msg_error() and ata_msg_intr() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 39/68] libata: drop ata_msg_ctl() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 40/68] libata: drop ata_msg_malloc() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 41/68] libata: drop ata_msg_warn() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 42/68] libata: drop ata_msg_probe() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 43/68] libata: drop ata_msg_info() Hannes Reinecke
2021-12-23  9:48   ` Sergey Shtylyov
2021-12-23 18:47     ` Sergey Shtylyov
2021-12-30  5:20       ` Damien Le Moal
2021-12-21  7:21 ` [PATCH 44/68] libata: drop ata_msg_drv() Hannes Reinecke
2021-12-21  7:21 ` [PATCH 45/68] libata: remove 'new' ata message handling Hannes Reinecke
2021-12-21  7:21 ` [PATCH 46/68] libata: remove debug compilation switches Hannes Reinecke
2021-12-21  7:21 ` [PATCH 47/68] pata_atp867x: convert printk() calls Hannes Reinecke
2021-12-21  7:21 ` [PATCH 48/68] pata_cmd640: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 49/68] pata_cmd64x: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 50/68] pata_cs5520: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 51/68] pata_cs5536: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 52/68] pata_cypress: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 53/68] pata_it821x: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 54/68] pata_marvell: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 55/68] pata_rz1000: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 56/68] pata_serverworks: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 57/68] pata_sil680: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 58/68] sata_sx4: " Hannes Reinecke
2021-12-21  7:21 ` [PATCH 59/68] sata_mv: convert remaining printk() to structured logging Hannes Reinecke
2021-12-21  7:21 ` [PATCH 60/68] pata_hpt37x: convert pr_XXX() calls Hannes Reinecke
2021-12-21  7:21 ` [PATCH 61/68] pata_octeon_cf: Replace pr_XXX() calls with structured logging Hannes Reinecke
2021-12-21  7:21 ` [PATCH 62/68] pata_hpt3x2n: convert pr_XXX() calls Hannes Reinecke
2021-12-21  7:21 ` [PATCH 63/68] sata_gemini: convert pr_err() calls Hannes Reinecke
2021-12-21  7:21 ` [PATCH 64/68] pata_hpt366: convert pr_warn() calls Hannes Reinecke
2021-12-21  7:21 ` [PATCH 65/68] libata-scsi: rework ata_dump_status to avoid using pr_cont() Hannes Reinecke
2021-12-30  5:13   ` Damien Le Moal
2021-12-21  7:21 ` [PATCH 66/68] sata_dwc_460ex: drop DEBUG_NCQ Hannes Reinecke
2021-12-21  7:21 ` [PATCH 67/68] sata_dwc_460ex: remove 'check_status' argument Hannes Reinecke
2021-12-21  7:21 ` [PATCH 68/68] sata_dwc_460ex: Remove debug compile options Hannes Reinecke
2021-12-30  5:19 ` [PATCHv3 00/68] libata: rework logging, take II Damien Le Moal
2021-12-30 13:47   ` Hannes Reinecke
2021-12-31  4:49     ` Damien Le Moal
2021-12-31  9:45       ` Hannes Reinecke
  -- strict thread matches above, loose matches on Subject: below --
2021-12-10  7:27 [PATCHv2 " Hannes Reinecke
2021-12-10  7:28 ` [PATCH 13/68] libata: revamp ata_get_cmd_descript() Hannes Reinecke
2021-12-12  9:33   ` Sergey Shtylyov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211221072131.46673-14-hare@suse.de \
    --to=hare@suse.de \
    --cc=damien.lemoal@wdc.com \
    --cc=linux-ide@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.